==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoring.md <==
# AwsOpsWorksMonitoring


```text
aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoring
```

```text
include('aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoring')
```



| Illustration | AwsOpsWorksMonitoring | AwsOpsWorksMonitoringCard | AwsOpsWorksMonitoringGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoring.png) | ![illustration for AwsOpsWorksMonitoring](../../../aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoring.Local.png) | ![illustration for AwsOpsWorksMonitoringCard](../../../aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoringCard.Local.png) | ![illustration for AwsOpsWorksMonitoringGroup](../../../aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoringGroup.Local.png) |




## AwsOpsWorksMonitoring

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsOpsWorksMonitoring
include('aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoring')

' renders the element
AwsOpsWorksMonitoring('AwsOpsWorksMonitoring', 'Aws Ops Works Monitoring', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsOpsWorksMonitoring
include('aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoring')

' renders the element
AwsOpsWorksMonitoring('AwsOpsWorksMonitoring', 'Aws Ops Works Monitoring', 'an optional tech label')
@enduml
```

## AwsOpsWorksMonitoringCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsOpsWorksMonitoringCard
include('aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoring')

' renders the element
AwsOpsWorksMonitoringCard('AwsOpsWorksMonitoringCard', 'Aws Ops Works Monitoring Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsOpsWorksMonitoringCard
include('aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoring')

' renders the element
AwsOpsWorksMonitoringCard('AwsOpsWorksMonitoringCard', 'Aws Ops Works Monitoring Card', 'an optional description')
@enduml
```

## AwsOpsWorksMonitoringGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsOpsWorksMonitoringGroup
include('aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoring')

' renders the element
AwsOpsWorksMonitoringGroup('AwsOpsWorksMonitoringGroup', 'Aws Ops Works Monitoring Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsOpsWorksMonitoringGroup
include('aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoring')

' renders the element
AwsOpsWorksMonitoringGroup('AwsOpsWorksMonitoringGroup', 'Aws Ops Works Monitoring Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoring.md <==
# AwsOpsWorksMonitoring


```text
aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoring
```

```text
include('aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoring')
```



| Illustration | AwsOpsWorksMonitoring | AwsOpsWorksMonitoringCard | AwsOpsWorksMonitoringGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoring.png) | ![illustration for AwsOpsWorksMonitoring](../../../aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoring.Local.png) | ![illustration for AwsOpsWorksMonitoringCard](../../../aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoringCard.Local.png) | ![illustration for AwsOpsWorksMonitoringGroup](../../../aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoringGroup.Local.png) |




## AwsOpsWorksMonitoring

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsOpsWorksMonitoring
include('aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoring')

' renders the element
AwsOpsWorksMonitoring('AwsOpsWorksMonitoring', 'Aws Ops Works Monitoring', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsOpsWorksMonitoring
include('aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoring')

' renders the element
AwsOpsWorksMonitoring('AwsOpsWorksMonitoring', 'Aws Ops Works Monitoring', 'an optional tech label')
@enduml
```

## AwsOpsWorksMonitoringCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsOpsWorksMonitoringCard
include('aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoring')

' renders the element
AwsOpsWorksMonitoringCard('AwsOpsWorksMonitoringCard', 'Aws Ops Works Monitoring Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsOpsWorksMonitoringCard
include('aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoring')

' renders the element
AwsOpsWorksMonitoringCard('AwsOpsWorksMonitoringCard', 'Aws Ops Works Monitoring Card', 'an optional description')
@enduml
```

## AwsOpsWorksMonitoringGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsOpsWorksMonitoringGroup
include('aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoring')

' renders the element
AwsOpsWorksMonitoringGroup('AwsOpsWorksMonitoringGroup', 'Aws Ops Works Monitoring Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsOpsWorksMonitoringGroup
include('aws-20210730/Resource/ManagementGovernance/AwsOpsWorksMonitoring')

' renders the element
AwsOpsWorksMonitoringGroup('AwsOpsWorksMonitoringGroup', 'Aws Ops Works Monitoring Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
